@@ -36,8 +36,8 @@ class ComputationPhase:
         self.input = input
         self.state = state
 
-        "Cached default input obtained from inputspec.json file to reuse during multiple iterations"
-        self.input_args = cache['input_args']
+        """Cached default input obtained from inputspec.json file to reuse during multiple iterations"""
+        self.input_args = FrozenDict(cache['input_args'])
 
         if not self.cache.get(self.id):
             self._initialize()
@@ -88,13 +88,12 @@ class PhasePipeline:
 
     def next_phase(self, jump_phase=False):
         current_phase_key = self.phase_ids[self.cache[self.id]['index']]
+        self.cache[self.id]['iterations'][current_phase_key] += 1
 
-        _is_single_iteration_phase = not self.multi_iterations[current_phase_key]
-        if jump_phase or _is_single_iteration_phase:
+        if jump_phase or not self.multi_iterations[current_phase_key]:
             if self.cache[self.id]['index'] < len(self.phases) - 1:
                 self.cache[self.id]['index'] += 1
 
-        self.cache[self.id]['iterations'][self.phase_ids[self.cache[self.id]['index']]] += 1
         return self.phase_ids[self.cache[self.id]['index']]
 
     def __str__(self):
